@@ -31,7 +31,12 @@ describe user('root') do
 end
 
 describe user('root') do
-  its(:minimum_days_between_password_change) { should  == 0 }
+  let(:stdout) { "$1$T0aTw9NJ$NdMldLUQ8WqhlEEGToNzl/\n" } 
+  its(:encrypted_password) { should eq '$1$T0aTw9NJ$NdMldLUQ8WqhlEEGToNzl/' } 
+end
+
+describe user('root') do
+  its(:minimum_days_between_password_change) { should == 0 }
 end
 
 describe user('root') do
